@@ -1,3 +1,18 @@
+isUseNamesNADefunct <- function() {
+  action <- getOption("matrixStats.useNames.NA", "defunct")
+  action <- match.arg(action, choices = c("deprecated", "defunct"))
+  (action == "defunct")
+}
+
+deprecatedUseNamesNA <- function() {
+  if (isUseNamesNADefunct()) {
+    .Defunct(msg = "useNames = NA is defunct. Instead, specify either useNames = TRUE or useNames = FALSE.", package = .packageName)
+  } else {
+    .Deprecated(msg = "useNames = NA is deprecated. Instead, specify either useNames = TRUE or useNames = FALSE.", package = .packageName)
+  }
+}
+
+
 defunctShouldBeMatrixOrDim <- function(x) {
   x_class <- sQuote(class(x)[1])
   x_name <- sQuote(as.character(substitute(x)))
