@@ -11,6 +11,13 @@
 #'
 #' @param differences An \code{\link[base]{integer}} specifying the order of
 #' difference.
+#' 
+#' @param useNames If \code{\link[base]{NA}}, the default behavior of the 
+#' function about naming support is remained. If \code{\link[base:logical]{FALSE}}, 
+#' no naming support is done. Else if \code{\link[base:logical]{TRUE}}, names 
+#' attributes of result are set.
+#' 
+#' 
 #'
 #' @return Returns a \code{\link[base]{numeric}} \code{\link[base]{vector}} of
 #' length N - \code{differences}.
@@ -24,7 +31,7 @@
 #' @keywords univar internal
 #'
 #' @export
-diff2 <- function(x, idxs = NULL, lag = 1L, differences = 1L, ...) {
+diff2 <- function(x, idxs = NULL, lag = 1L, differences = 1L, ..., useNames = TRUE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -41,5 +48,5 @@ diff2 <- function(x, idxs = NULL, lag = 1L, differences = 1L, ...) {
   lag <- as.integer(lag)
   differences <- as.integer(differences)
 
-  .Call(C_diff2, x, idxs, lag, differences)
+  .Call(C_diff2, x, idxs, lag, differences, useNames)
 }
