@@ -18,7 +18,7 @@
 #' cf. \code{\link[base]{[}}().
 #' @keywords utilities
 #' @export
-rowCollapse <- function(x, idxs, rows = NULL, dim. = dim(x), ..., useNames = NA) {
+rowCollapse <- function(x, idxs, rows = NULL, dim. = dim(x), ..., useNames = TRUE) {
   # Argument 'x':
   if (!is.matrix(x) && !is.vector(x)) defunctShouldBeMatrixOrVector(x)
 
@@ -54,14 +54,16 @@ rowCollapse <- function(x, idxs, rows = NULL, dim. = dim(x), ..., useNames = NA)
     } else {
       names(res) <- NULL
     }
-  }
+  } else {
+    deprecatedUseNamesNA()
+  }  
 
   res
 }
 
 #' @rdname rowCollapse
 #' @export
-colCollapse <- function(x, idxs, cols = NULL, dim. = dim(x), ..., useNames = NA) {
+colCollapse <- function(x, idxs, cols = NULL, dim. = dim(x), ..., useNames = TRUE) {
   # Argument 'x':
   if (!is.matrix(x) && !is.vector(x)) defunctShouldBeMatrixOrVector(x)
 
