@@ -10,9 +10,14 @@
 #' @param probs A \code{\link[base]{numeric}} \code{\link[base]{vector}} of J
 #' probabilities in [0, 1].
 #'
-#' @param type An \code{\link[base]{integer}} specify the type of estimator.
+#' @param type An \code{\link[base]{integer}} specifying the type of estimator.
 #' See \code{\link[stats]{quantile}} for more details.
 #'
+#' @param digits An \code{\link[base]{integer}} specifying the precision of
+#' the formatted percentages. Not used when `useNames = FALSE`.
+#' In **matrixStats** (< 0.63.0), the default used to be
+#' `max(2L, getOption("digits"))` inline with R (< 4.1.0).
+#'
 #' @param ... Additional arguments passed to \code{\link[stats]{quantile}}.
 #'
 #' @param drop If TRUE, singleton dimensions in the result are dropped,
@@ -32,7 +37,8 @@
 #' @export
 rowQuantiles <- function(x, rows = NULL, cols = NULL,
                          probs = seq(from = 0, to = 1, by = 0.25),
-                         na.rm = FALSE, type = 7L, ..., useNames = NA, drop = TRUE) {
+                         na.rm = FALSE, type = 7L, digits = 7L,
+                         ..., useNames = TRUE, drop = TRUE) {
   # Argument 'x':
   if (!is.matrix(x)) defunctShouldBeMatrix(x)
   if (!is.numeric(x) && !is.integer(x) && !is.logical(x)) {
@@ -127,18 +133,25 @@ rowQuantiles <- function(x, rows = NULL, cols = NULL,
       for (kk in rows) {
         xkk <- x[kk, ]
         if (na.rm) xkk <- xkk[!is.na(xkk)]
-        q[kk, ] <- quantile(xkk, probs = probs, na.rm = FALSE, type = type, ...)
+        q[kk, ] <- quantile(xkk, probs = probs, na.rm = FALSE, type = type, names = FALSE, ...)
       }
     } # if (type ...)
   }
 
-  # Add dim names
-  digits <- max(2L, getOption("digits"))
-  colnames(q) <- sprintf("%.*g%%", digits, 100 * probs)
-  
   # Preserve names attribute?
-  if (is.na(useNames) || useNames) {
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
     rownames(q) <- rownames(x)
+    # Add percentage names
+    if (length(probs) > 0) {
+      colnames(q) <- quantile_probs_names(probs, digits = digits)
+    }
+  } else if (useNames) {
+    rownames(q) <- rownames(x)
+    # Add percentage names
+    if (length(probs) > 0) {
+      colnames(q) <- quantile_probs_names(probs, digits = digits)
+    }
   } else {
     rownames(q) <- NULL
   }
@@ -156,7 +169,8 @@ rowQuantiles <- function(x, rows = NULL, cols = NULL,
 #' @export
 colQuantiles <- function(x, rows = NULL, cols = NULL,
                          probs = seq(from = 0, to = 1, by = 0.25),
-                         na.rm = FALSE, type = 7L, ..., useNames = NA, drop = TRUE) {
+                         na.rm = FALSE, type = 7L, digits = 7L,
+                         ..., useNames = TRUE, drop = TRUE) {
   # Argument 'x':
   if (!is.matrix(x)) defunctShouldBeMatrix(x)
   if (!is.numeric(x) && !is.integer(x) && !is.logical(x)) {
@@ -249,18 +263,25 @@ colQuantiles <- function(x, rows = NULL, cols = NULL,
       for (kk in cols) {
         xkk <- x[, kk]
         if (na.rm) xkk <- xkk[!is.na(xkk)]
-        q[kk, ] <- quantile(xkk, probs = probs, na.rm = FALSE, type = type, ...)
+        q[kk, ] <- quantile(xkk, probs = probs, na.rm = FALSE, type = type, names = FALSE, ...)
       }
     } # if (type ...)    
   }
 
-  # Add dim names
-  digits <- max(2L, getOption("digits"))
-  colnames(q) <- sprintf("%.*g%%", digits, 100 * probs)
-  
   # Preserve names attribute?
-  if (is.na(useNames) || useNames) {
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
     rownames(q) <- colnames(x)
+    # Add percentage names
+    if (length(probs) > 0) {
+      colnames(q) <- quantile_probs_names(probs, digits = digits)
+    }
+  } else if (useNames) {
+    rownames(q) <- colnames(x)
+    # Add percentage names
+    if (length(probs) > 0) {
+      colnames(q) <- quantile_probs_names(probs, digits = digits)
+    }
   } else {
     rownames(q) <- NULL
   }
@@ -272,3 +293,20 @@ colQuantiles <- function(x, rows = NULL, cols = NULL,
 
   q
 }
+
+
+quantile_probs_names <- function(probs, digits = 7L) {
+  if (!is.numeric(digits) || is.na(digits) || digits < 1L) {
+    stop("Argument 'digits' is not a single positive numeric")
+  }
+  ## Adopted from stats:::format_perc()
+  probs <- 100 * probs
+  if (length(probs) < 100) {
+    names <- formatC(probs, format = "fg", width = 1L, digits = digits)
+  } else {
+    names <- format(probs, trim = TRUE, digits = digits)
+  }
+  names <- paste(names, "%", sep = "")
+  names[is.na(probs)] <- ""
+  names
+}
