@@ -17,16 +17,11 @@
 #' correction factor needs to be applied manually, i.e. there is no
 #' \code{constant} argument for the IQR functions.
 #'
+#' @inheritParams rowAlls
+#'
 #' @param x A \code{\link[base]{numeric}} \code{\link[base]{vector}} of length
 #' N or a \code{\link[base]{numeric}} NxK \code{\link[base]{matrix}}.
 #'
-#' @param idxs,rows,cols A \code{\link[base]{vector}} indicating subset of
-#' elements (or rows and/or columns) to operate over. If
-#' \code{\link[base]{NULL}}, no subsetting is done.
-#'
-#' @param na.rm If \code{\link[base:logical]{TRUE}}, \code{\link[base]{NA}}s
-#' are excluded, otherwise not.
-#'
 #' @param diff The positional distance of elements for which the difference
 #' should be calculated.
 #'
@@ -37,8 +32,6 @@
 #' @param constant A scale factor adjusting for asymptotically normal
 #' consistency.
 #'
-#' @param ... Not used.
-#'
 #' @return Returns a \code{\link[base]{numeric}} \code{\link[base]{vector}} of
 #' length 1, length N, or length K.
 #'
@@ -55,6 +48,9 @@
 #' @keywords iteration robust univar
 #' @export
 varDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0, ...) {
+  if (length(diff) != 1L) stop(sprintf("Argument '%s' is not scalar: %d", "diff", length(diff)))
+  if (diff < 0L) stop(sprintf("Argument '%s' must not be negative: %d", "diff", diff))
+  
   # Apply subset
   if (!is.null(idxs)) x <- x[idxs]
 
@@ -98,6 +94,9 @@ varDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0, ...) {
 #' @rdname varDiff
 #' @export
 sdDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0, ...) {
+  if (length(diff) != 1L) stop(sprintf("Argument '%s' is not scalar: %d", "diff", length(diff)))
+  if (diff < 0L) stop(sprintf("Argument '%s' must not be negative: %d", "diff", diff))
+  
   # Apply subset
   if (!is.null(idxs)) x <- x[idxs]
 
@@ -142,6 +141,9 @@ sdDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0, ...) {
 #' @export
 madDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0,
                     constant = 1.4826, ...) {
+  if (length(diff) != 1L) stop(sprintf("Argument '%s' is not scalar: %d", "diff", length(diff)))
+  if (diff < 0L) stop(sprintf("Argument '%s' must not be negative: %d", "diff", diff))
+  
   # Apply subset
   if (!is.null(idxs)) x <- x[idxs]
 
@@ -185,6 +187,9 @@ madDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0,
 #' @rdname varDiff
 #' @export
 iqrDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0, ...) {
+  if (length(diff) != 1L) stop(sprintf("Argument '%s' is not scalar: %d", "diff", length(diff)))
+  if (diff < 0L) stop(sprintf("Argument '%s' must not be negative: %d", "diff", diff))
+  
   # Apply subset
   if (!is.null(idxs)) x <- x[idxs]
 
@@ -236,11 +241,18 @@ iqrDiff <- function(x, idxs = NULL, na.rm = FALSE, diff = 1L, trim = 0, ...) {
 #' @rdname varDiff
 #' @export
 rowVarDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                        trim = 0, ...) {
+                        trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    rownames(x) <- NULL
+  }
 
   apply(x, MARGIN = 1L, FUN = varDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
@@ -250,11 +262,18 @@ rowVarDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
 #' @rdname varDiff
 #' @export
 colVarDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                        trim = 0, ...) {
+                        trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    colnames(x) <- NULL
+  }
 
   apply(x, MARGIN = 2L, FUN = varDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
@@ -264,11 +283,18 @@ colVarDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
 #' @rdname varDiff
 #' @export
 rowSdDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                       trim = 0, ...) {
+                       trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    rownames(x) <- NULL
+  }
 
   apply(x, MARGIN = 1L, FUN = sdDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
@@ -278,11 +304,18 @@ rowSdDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
 #' @rdname varDiff
 #' @export
 colSdDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                       trim = 0, ...) {
+                       trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    colnames(x) <- NULL
+  }
 
   apply(x, MARGIN = 2L, FUN = sdDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
@@ -292,11 +325,18 @@ colSdDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
 #' @rdname varDiff
 #' @export
 rowMadDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                        trim = 0, ...) {
+                        trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    rownames(x) <- NULL
+  }
 
   apply(x, MARGIN = 1L, FUN = madDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
@@ -306,11 +346,18 @@ rowMadDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
 #' @rdname varDiff
 #' @export
 colMadDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                        trim = 0, ...) {
+                        trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    colnames(x) <- NULL
+  }
 
   apply(x, MARGIN = 2L, FUN = madDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
@@ -320,11 +367,18 @@ colMadDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
 #' @rdname varDiff
 #' @export
 rowIQRDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                        trim = 0, ...) {
+                        trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    rownames(x) <- NULL
+  }
 
   apply(x, MARGIN = 1L, FUN = iqrDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
@@ -334,11 +388,18 @@ rowIQRDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
 #' @rdname varDiff
 #' @export
 colIQRDiffs <- function(x, rows = NULL, cols = NULL, na.rm = FALSE, diff = 1L,
-                        trim = 0, ...) {
+                        trim = 0, ..., useNames = TRUE) {
   # Apply subset
   if (!is.null(rows) && !is.null(cols)) x <- x[rows, cols, drop = FALSE]
   else if (!is.null(rows)) x <- x[rows, , drop = FALSE]
   else if (!is.null(cols)) x <- x[, cols, drop = FALSE]
+  
+  # Preserve names attribute?
+  if (is.na(useNames)) {
+    deprecatedUseNamesNA()
+  } else if (!useNames) {
+    colnames(x) <- NULL
+  }
 
   apply(x, MARGIN = 2L, FUN = iqrDiff,
         na.rm = na.rm, diff = diff, trim = trim, ...)
