@@ -47,31 +47,34 @@ dimnames <- list(letters[1:6], LETTERS[1:6])
 for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
+  
+  count <- 0L
   for (rows in index_cases) {
     for (cols in index_cases) {
-      for (na.rm in c(TRUE, FALSE)) {
-        for (useNames in c(NA, TRUE, FALSE)) {
-          validateIndicesTestMatrix(x, rows, cols,
-                                    ftest = rowRanges, fsure = rowRanges_R,
-                                    na.rm = na.rm, useNames = useNames)
-          validateIndicesTestMatrix(x, rows, cols,
-                                    ftest = rowMins, fsure = rowMins_R,
-                                    na.rm = na.rm, useNames = useNames)
-          validateIndicesTestMatrix(x, rows, cols,
-                                    ftest = rowMaxs, fsure = rowMaxs_R,
-                                    na.rm = na.rm, useNames = useNames)
-    
-          validateIndicesTestMatrix(x, rows, cols,
-                                    fcoltest = colRanges, fsure = rowRanges_R,
-                                    na.rm = na.rm, useNames = useNames)
-          validateIndicesTestMatrix(x, rows, cols,
-                                    fcoltest = colMins, fsure = rowMins_R,
-                                    na.rm = na.rm, useNames = useNames)
-          validateIndicesTestMatrix(x, rows, cols,
-                                    fcoltest = colMaxs, fsure = rowMaxs_R,
-                                    na.rm = na.rm, useNames = useNames)
-        }
-      }
+      count <- count + 1L
+      na.rm <- c(TRUE, FALSE)[count %% 2 + 1]
+      useNames <- c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)
+      useNames <- useNames[count %% length(useNames) + 1]
+
+      validateIndicesTestMatrix(x, rows, cols,
+                                ftest = rowRanges, fsure = rowRanges_R,
+                                na.rm = na.rm, useNames = useNames)
+      validateIndicesTestMatrix(x, rows, cols,
+                                ftest = rowMins, fsure = rowMins_R,
+                                na.rm = na.rm, useNames = useNames)
+      validateIndicesTestMatrix(x, rows, cols,
+                                ftest = rowMaxs, fsure = rowMaxs_R,
+                                na.rm = na.rm, useNames = useNames)
+
+      validateIndicesTestMatrix(x, rows, cols,
+                                fcoltest = colRanges, fsure = rowRanges_R,
+                                na.rm = na.rm, useNames = useNames)
+      validateIndicesTestMatrix(x, rows, cols,
+                                fcoltest = colMins, fsure = rowMins_R,
+                                na.rm = na.rm, useNames = useNames)
+      validateIndicesTestMatrix(x, rows, cols,
+                                fcoltest = colMaxs, fsure = rowMaxs_R,
+                                na.rm = na.rm, useNames = useNames)
     }
   }
 }
